@@ -9,6 +9,9 @@ __all__ = [
 ]
 
 def ValueDtypeParser(v, dtype, ndigits=4):
+    params = locals()
+    info1 = f'params: {params}'
+    info2 = f'v: {v} {type(v)}'
     try:
         if dtype == 'int':
             return iNumber(v)
@@ -21,9 +24,12 @@ def ValueDtypeParser(v, dtype, ndigits=4):
         elif dtype in ['date','time','dt','datetime']:
             return DatetimeParser(v)
         elif dtype == 'str':
-            return v
+            return str(v)
         else:
-            logger.exception(f"정의되지 않은 데이타-타입({dtype})을 입력했다. {locals()}")
+            msg = f"정의되지 않은 데이타-타입({dtype})을 입력하면, 입력된 값을 그대로 반환한다."
+            logger.warning(f'{msg}-->\n{info1}\n{info2}')
+            return v
     except Exception as e:
-        logger.exception(f"파싱 에러가 발생하면, 입력된 값을 그대로 반환한다. {locals()}")
+        msg = '파싱 에러가 발생하면, 입력된 값을 그대로 반환한다.'
+        logger.error(f'{msg}-->\n{info1}\n{info2}')
         return v
