@@ -5,6 +5,9 @@ from pathlib import PureWindowsPath, PurePosixPath
 from idebug import *
 
 
+__all__ = [
+    'clean_path',
+]
 
 
 def clean_path(p):
